==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/es.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'es', {
	acccessKey: 'Tecla de Acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de Contenido',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Referencia',
		menu: 'Propiedades de Referencia',
		title: 'Propiedades de Referencia',
		name: 'Nombre de la Referencia',
		errorName: 'Por favor, complete el nombre de la Referencia',
		remove: 'Quitar Referencia'
	},
	anchorId: 'Por ID de elemento',
	anchorName: 'Por Nombre de Referencia',
	charset: 'Fuente de caracteres vinculado',
	cssClasses: 'Clases de hojas de estilo',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Dirección de E-Mail',
	emailBody: 'Cuerpo del Mensaje',
	emailSubject: 'Título del Mensaje',
	id: 'Id',
	info: 'Información de Vínculo',
	langCode: 'Código idioma',
	langDir: 'Orientación',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar Vínculo',
	name: 'Nombre',
	noAnchors: '(No hay referencias disponibles en el documento)',
	noEmail: 'Por favor escriba la dirección de e-mail',
	noUrl: 'Por favor escriba el vínculo URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<otro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Características de Ventana Emergente',
	popupFullScreen: 'Pantalla Completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Barra de ubicación',
	popupMenuBar: 'Barra de Menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de Estado',
	popupToolbar: 'Barra de Herramientas',
	popupTop: 'Posición Derecha',
	rel: 'Relación',
	selectAnchor: 'Seleccionar una referencia',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nombre del Marco Destino',
	targetPopup: '<ventana emergente>',
	targetPopupName: 'Nombre de Ventana Emergente',
	title: 'Vínculo',
	toAnchor: 'Referencia en esta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Insertar/Editar Vínculo',
	type: 'Tipo de vínculo',
	unlink: 'Eliminar Vínculo',
	upload: 'Cargar'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/es.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'es', {
	acccessKey: 'Tecla de Acceso',
	advanced: 'Avanzado',
	advisoryContentType: 'Tipo de Contenido',
	advisoryTitle: 'Título',
	anchor: {
		toolbar: 'Referencia',
		menu: 'Propiedades de Referencia',
		title: 'Propiedades de Referencia',
		name: 'Nombre de la Referencia',
		errorName: 'Por favor, complete el nombre de la Referencia',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Quitar Referencia'
	},
	anchorId: 'Por ID de elemento',
	anchorName: 'Por Nombre de Referencia',
	charset: 'Fuente de caracteres vinculado',
	cssClasses: 'Clases de hojas de estilo',
	download: 'Forzar la descarga',
	displayText: 'Mostrar texto',
	emailAddress: 'Dirección de E-Mail',
	emailBody: 'Cuerpo del Mensaje',
	emailSubject: 'Título del Mensaje',
	id: 'Id',
	info: 'Información de Vínculo',
	langCode: 'Código idioma',
	langDir: 'Orientación',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar Vínculo',
	name: 'Nombre',
	noAnchors: '(No hay referencias disponibles en el documento)',
	noEmail: 'Por favor escriba la dirección de e-mail',
	noUrl: 'Por favor escriba el vínculo URL',
	noTel: 'Por favor ingrese el numero de telefono',
	other: '<otro>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Características de Ventana Emergente',
	popupFullScreen: 'Pantalla Completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Barra de ubicación',
	popupMenuBar: 'Barra de Menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de Estado',
	popupToolbar: 'Barra de Herramientas',
	popupTop: 'Posición Derecha',
	rel: 'Relación',
	selectAnchor: 'Seleccionar una referencia',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Destino',
	targetFrame: '<marco>',
	targetFrameName: 'Nombre del Marco Destino',
	targetPopup: '<ventana emergente>',
	targetPopupName: 'Nombre de Ventana Emergente',
	title: 'Vínculo',
	toAnchor: 'Referencia en esta página',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Teléfono',
	toolbar: 'Insertar/Editar Vínculo',
	type: 'Tipo de vínculo',
	unlink: 'Eliminar Vínculo',
	upload: 'Cargar'
} );
